@@ -134,6 +134,7 @@ these flags can also be set within an RE:
                      newline) as well as the end of the string.
     R  r  REVERSE    Searches backwards.
     S  s  DOTALL     "." matches any character at all, including the newline.
+    W  w  WORD       Default Unicode word breaks.
     X  x  VERBOSE    Ignore whitespace and comments for nicer looking RE's.
     U  u  UNICODE    Make \w, \W, \b, \B, \d, and \D dependent on the Unicode
                      locale. Default when matching a Unicode string.
@@ -253,7 +254,7 @@ import _regex_core as _rc
 _cache = {}
 
 # Maximum size of the cache.
-_MAXCACHE = 1024
+_MAXCACHE = 500
 
 def _compile(pattern, flags=0):
     "Compiles a regular expression to a PatternObject. "
@@ -329,7 +330,7 @@ def _compile(pattern, flags=0):
 
     # Store the compiled pattern.
     if len(_cache) >= _MAXCACHE:
-        _cache.clear()
+        _rc._shrink_cache(_cache, _MAXCACHE)
     _cache[key] = p
 
     return p
@@ -369,20 +370,17 @@ def _compile_replacement(pattern, template):
         compiled.append(make_string(literal))
     return compiled
 
-if __name__ == "__main__":
-    _rc._create_header_file(dir())
-else:
-    import _regex
-    _regex.set_exception(error)
+import _regex
+_regex.set_exception(error)
 
-    # We define _pattern_type here after all the support objects have been
-    # defined.
-    _pattern_type = type(_compile("", 0))
+# We define _pattern_type here after all the support objects have been
+# defined.
+_pattern_type = type(_compile("", 0))
 
-    # Register myself for pickling.
-    import copy_reg
+# Register myself for pickling.
+import copy_reg
 
-    def _pickle(p):
-        return _compile, (p.pattern, p.flags)
+def _pickle(p):
+    return _compile, (p.pattern, p.flags)
 
-    copy_reg.pickle(_pattern_type, _pickle, _compile)
+copy_reg.pickle(_pattern_type, _pickle, _compile)
