@@ -4,8 +4,8 @@ import unicodedata
 from weakref import proxy
 
 class Test:
-    MATCH_CLASS = "<type '_regex.REGEX_Match'>"
-    PATTERN_CLASS = "<type '_regex.REGEX_Pattern'>"
+    MATCH_CLASS = "<type '_regex.Match'>"
+    PATTERN_CLASS = "<type '_regex.Pattern'>"
     FLAGS_WITH_COMPILED_PAT = """ValueError("can't process flags argument with a compiled pattern",)"""
     INVALID_GROUP_REF = "error('invalid group reference',)"
     MISSING_GT = "error('missing >',)"
@@ -399,6 +399,11 @@ class Test:
         self.expect(lambda: regex.match("^x{1,2}$", "xxx"), "None")
         self.expect(lambda: regex.match("^x{1,2}?$", "xxx"), "None")
 
+        self.expect(lambda: regex.match("^x{1}", "xxx")[0], "'x'")
+        self.expect(lambda: regex.match("^x{1}?", "xxx")[0], "'x'")
+        self.expect(lambda: regex.match("^x{0,1}", "xxx")[0], "'x'")
+        self.expect(lambda: regex.match("^x{0,1}?", "xxx")[0], "''")
+
         self.expect(lambda: type(regex.match("^x{3}$", "xxx")),
           self.MATCH_CLASS)
         self.expect(lambda: type(regex.match("^x{1,3}$", "xxx")),
@@ -446,10 +451,10 @@ class Test:
           regex.LOCALE)[1], "'bx'")
         self.expect(lambda: regex.search(r"\B(b.)\B", "abc bcd bc abxd",
           regex.LOCALE)[1], "'bx'")
-        self.expect(lambda: regex.search(r"\b(b.)\b", "abcd abc bcd bx",
-          regex.UNICODE)[1], "'bx'")
-        self.expect(lambda: regex.search(r"\B(b.)\B", "abc bcd bc abxd",
-          regex.UNICODE)[1], "'bx'")
+        self.expect(lambda: regex.search(ur"\b(b.)\b", u"abcd abc bcd bx",
+          regex.UNICODE)[1], "u'bx'")
+        self.expect(lambda: regex.search(ur"\B(b.)\B", u"abc bcd bc abxd",
+          regex.UNICODE)[1], "u'bx'")
         self.expect(lambda: regex.search(r"^abc$", "\nabc\n", regex.M)[0],
           "'abc'")
         self.expect(lambda: regex.search(r"^\Aabc\Z$", "abc", regex.M)[0],
@@ -470,8 +475,8 @@ class Test:
           "'1aa! a'")
         self.expect(lambda: regex.search(r"\d\D\w\W\s\S", "1aa! a",
           regex.LOCALE)[0], "'1aa! a'")
-        self.expect(lambda: regex.search(r"\d\D\w\W\s\S", "1aa! a",
-          regex.UNICODE)[0], "'1aa! a'")
+        self.expect(lambda: regex.search(ur"\d\D\w\W\s\S", u"1aa! a",
+          regex.UNICODE)[0], "u'1aa! a'")
 
     def test_bigcharset(self):
         self.expect(lambda: regex.match(ur"(?u)([\u2222\u2223])",
@@ -482,11 +487,11 @@ class Test:
           u"e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
           r"u'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
         self.expect(lambda:
-          u"".join(regex.findall(u"[e\xe8\xe9\xea\xeb\u0113\u011b\u0117]",
+          u"".join(regex.findall(ur"[e\xe8\xe9\xea\xeb\u0113\u011b\u0117]",
           u"e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
           r"u'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
         self.expect(lambda:
-          u"".join(regex.findall(u"e|\xe8|\xe9|\xea|\xeb|\u0113|\u011b|\u0117",
+          u"".join(regex.findall(ur"e|\xe8|\xe9|\xea|\xeb|\u0113|\u011b|\u0117",
           u"e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
           r"u'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
 
@@ -1007,6 +1012,9 @@ class Test:
         self.expect(lambda: regex.search("(?ir)abcdef", "ABCDEF").span(),
           "(0, 6)")
 
+        self.expect(lambda: regex.sub(r"(.)", r"\1", "abc"), "'abc'")
+        self.expect(lambda: regex.sub(r"(?r)(.)", r"\1", "abc"), "'abc'")
+
     def test_atomic(self):
         # Issue 433030.
         self.expect(lambda: regex.search(r"(?>a*)a", "aa"), "None")
@@ -1193,6 +1201,30 @@ class Test:
           u"a\xE0a\u0300e\xE9e\u0301"),
           "[u'a\\xe0a\\u0300', u'e\\xe9e\\u0301']")
 
+    def test_word_boundary(self):
+        text = u'The quick ("brown") fox can\'t jump 32.3 feet, right?'
+        self.expect(lambda: regex.split(ur'(?z)\b', text), repr([u'', u'The',
+          u' ', u'quick', u' ("', u'brown', u'") ', u'fox', u' ', u'can', u"'",
+          u't', u' ', u'jump', u' ', u'32', u'.', u'3', u' ', u'feet', u', ',
+          u'right', u'?']))
+        self.expect(lambda: regex.split(ur'(?wz)\b', text), repr([u'', u'The',
+          u' ', u'quick', u' ', u'(', u'"', u'brown', u'"', u')', u' ', u'fox',
+          u' ', u"can't", u' ', u'jump', u' ', u'32.3', u' ', u'feet', u',',
+          u' ', u'right', u'?', u'']))
+
+        text = u"The  fox"
+        self.expect(lambda: regex.split(ur'(?z)\b', text), repr([u'', u'The',
+          u'  ', u'fox', u'']))
+        self.expect(lambda: regex.split(ur'(?wz)\b', text), repr([u'', u'The',
+          u' ', u' ', u'fox', u'']))
+
+        text = u"can't aujourd'hui l'objectif"
+        self.expect(lambda: regex.split(ur'(?z)\b', text), repr([u'', u'can',
+          u"'", u't', u' ', u'aujourd', u"'", u'hui', u' ', u'l', u"'",
+          u'objectif', u'']))
+        self.expect(lambda: regex.split(ur'(?wz)\b', text), repr([u'',
+          u"can't", u' ', u"aujourd'hui", u' ', u"l'", u'objectif', u'']))
+
     def test_branch_reset(self):
         self.expect(lambda: regex.match(r"(?:(a)|(b))(c)", "ac").groups(),
           "('a', None, 'c')")
