@@ -4,8 +4,8 @@ import unicodedata
 from weakref import proxy
 
 class Test:
-    MATCH_CLASS = "<class '_regex.REGEX_Match'>"
-    PATTERN_CLASS = "<class '_regex.REGEX_Pattern'>"
+    MATCH_CLASS = "<class '_regex.Match'>"
+    PATTERN_CLASS = "<class '_regex.Pattern'>"
     FLAGS_WITH_COMPILED_PAT = """ValueError("can't process flags argument with a compiled pattern",)"""
     INVALID_GROUP_REF = "error('invalid group reference',)"
     MISSING_GT = "error('missing >',)"
@@ -381,6 +381,11 @@ class Test:
         self.expect(lambda: regex.match("^x{1,2}$", "xxx"), "None")
         self.expect(lambda: regex.match("^x{1,2}?$", "xxx"), "None")
 
+        self.expect(lambda: regex.match("^x{1}", "xxx")[0], "'x'")
+        self.expect(lambda: regex.match("^x{1}?", "xxx")[0], "'x'")
+        self.expect(lambda: regex.match("^x{0,1}", "xxx")[0], "'x'")
+        self.expect(lambda: regex.match("^x{0,1}?", "xxx")[0], "''")
+
         self.expect(lambda: type(regex.match("^x{3}$", "xxx")),
           self.MATCH_CLASS)
         self.expect(lambda: type(regex.match("^x{1,3}$", "xxx")),
@@ -425,10 +430,10 @@ class Test:
           "'bx'")
         self.expect(lambda: regex.search(r"\B(b.)\B", "abc bcd bc abxd")[1],
           "'bx'")
-        self.expect(lambda: regex.search(r"\b(b.)\b", "abcd abc bcd bx",
-          regex.LOCALE)[1], "'bx'")
-        self.expect(lambda: regex.search(r"\B(b.)\B", "abc bcd bc abxd",
-          regex.LOCALE)[1], "'bx'")
+        self.expect(lambda: regex.search(br"\b(b.)\b", b"abcd abc bcd bx",
+          regex.LOCALE)[1], "b'bx'")
+        self.expect(lambda: regex.search(br"\B(b.)\B", b"abc bcd bc abxd",
+          regex.LOCALE)[1], "b'bx'")
         self.expect(lambda: regex.search(r"\b(b.)\b", "abcd abc bcd bx",
           regex.UNICODE)[1], "'bx'")
         self.expect(lambda: regex.search(r"\B(b.)\B", "abc bcd bc abxd",
@@ -451,8 +456,8 @@ class Test:
           regex.M), "None")
         self.expect(lambda: regex.search(r"\d\D\w\W\s\S", "1aa! a")[0],
           "'1aa! a'")
-        self.expect(lambda: regex.search(r"\d\D\w\W\s\S", "1aa! a",
-          regex.LOCALE)[0], "'1aa! a'")
+        self.expect(lambda: regex.search(br"\d\D\w\W\s\S", b"1aa! a",
+          regex.LOCALE)[0], "b'1aa! a'")
         self.expect(lambda: regex.search(r"\d\D\w\W\s\S", "1aa! a",
           regex.UNICODE)[0], "'1aa! a'")
 
@@ -465,11 +470,11 @@ class Test:
           "e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
           r"'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
         self.expect(lambda:
-          "".join(regex.findall("[e\xe8\xe9\xea\xeb\u0113\u011b\u0117]",
+          "".join(regex.findall(r"[e\xe8\xe9\xea\xeb\u0113\u011b\u0117]",
           "e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
           r"'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
         self.expect(lambda:
-          "".join(regex.findall("e|\xe8|\xe9|\xea|\xeb|\u0113|\u011b|\u0117",
+          "".join(regex.findall(r"e|\xe8|\xe9|\xea|\xeb|\u0113|\u011b|\u0117",
           "e\xe8\xe9\xea\xeb\u0113\u011b\u0117", flags=regex.UNICODE)),
           r"'e\xe8\xe9\xea\xeb\u0113\u011b\u0117'")
 
@@ -1028,6 +1033,9 @@ class Test:
         self.expect(lambda: regex.search("(?ir)abcdef", "ABCDEF").span(),
           "(0, 6)")
 
+        self.expect(lambda: regex.sub(r"(.)", r"\1", "abc"), "'abc'")
+        self.expect(lambda: regex.sub(r"(?r)(.)", r"\1", "abc"), "'abc'")
+
     def test_atomic(self):
         # Issue 433030.
         self.expect(lambda: regex.search(r"(?>a*)a", "aa"), "None")
@@ -1214,6 +1222,30 @@ class Test:
           "a\xE0a\u0300e\xE9e\u0301"),
           "['a\\xe0a\\u0300', 'e\\xe9e\\u0301']")
 
+    def test_word_boundary(self):
+        text = 'The quick ("brown") fox can\'t jump 32.3 feet, right?'
+        self.expect(lambda: regex.split(r'(?z)\b', text), ascii(['', 'The',
+          ' ', 'quick', ' ("', 'brown', '") ', 'fox', ' ', 'can', "'",
+          't', ' ', 'jump', ' ', '32', '.', '3', ' ', 'feet', ', ',
+          'right', '?']))
+        self.expect(lambda: regex.split(r'(?wz)\b', text), ascii(['', 'The',
+          ' ', 'quick', ' ', '(', '"', 'brown', '"', ')', ' ', 'fox',
+          ' ', "can't", ' ', 'jump', ' ', '32.3', ' ', 'feet', ',',
+          ' ', 'right', '?', '']))
+
+        text = "The  fox"
+        self.expect(lambda: regex.split(r'(?z)\b', text), ascii(['', 'The',
+          '  ', 'fox', '']))
+        self.expect(lambda: regex.split(r'(?wz)\b', text), ascii(['', 'The',
+          ' ', ' ', 'fox', '']))
+
+        text = "can't aujourd'hui l'objectif"
+        self.expect(lambda: regex.split(r'(?z)\b', text), ascii(['', 'can',
+          "'", 't', ' ', 'aujourd', "'", 'hui', ' ', 'l', "'",
+          'objectif', '']))
+        self.expect(lambda: regex.split(r'(?wz)\b', text), ascii(['',
+          "can't", ' ', "aujourd'hui", ' ', "l'", 'objectif', '']))
+
     def test_branch_reset(self):
         self.expect(lambda: regex.match(r"(?:(a)|(b))(c)", "ac").groups(),
           "('a', None, 'c')")
